fnss.topologies.datacenter.DatacenterTopology.selfloop_edges — FNSS 0.7.0 documentation

# fnss.topologies.datacenter.DatacenterTopology.selfloop_edges

`DatacenterTopology.` `selfloop_edges`(data=False, default=None)

  Return a list of selfloop edges.

  A selfloop edge has the same node at both ends.

  Parameters: | data : string or bool, optional (default=False) Return selfloop edges as two tuples (u,v) (data=False) or three-tuples (u,v,datadict) (data=True) or three-tuples (u,v,datavalue) (data=’attrname’) default : value, optional (default=None) Value used for edges that dont have the requested attribute. Only relevant if data is not True or False.
  Returns: | edgelist : list of edge tuples A list of all selfloop edges.

  See also

  `nodes_with_selfloops`, `number_of_selfloops`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_edge(1,1)
      >>> G.add_edge(1,2)
      >>> G.selfloop_edges()
      [(1, 1)]
      >>> G.selfloop_edges(data=True)
      [(1, 1, {})]